@@ -1,22 +1,26 @@
-#S3 methods
+#S3 method generics
 
+changeModelOnIC <- function(asrtests.obj, ...) UseMethod("changeModelOnIC")
 changeTerms <- function(asrtests.obj, ...) UseMethod("changeTerms")
-chooseModel <- function(asrtests.obj, ...) UseMethod("chooseModel")
+chooseModel <- function(object, ...) UseMethod("chooseModel")
+getTestPvalue <- function(asrtests.obj, ...) UseMethod("getTestPvalue")
+iterate <- function(asrtests.obj, ...) UseMethod("iterate")
 recalcWaldTab <- function(asrtests.obj, ...) UseMethod("recalcWaldTab")
 rmboundary <- function(asrtests.obj, ...) UseMethod("rmboundary")
 reparamSigDevn <- function(asrtests.obj, ...) UseMethod("reparamSigDevn")
 testranfix <- function(asrtests.obj, ...) UseMethod("testranfix")
 testresidual <- function(asrtests.obj, ...) UseMethod("testresidual")
 testswapran <- function(asrtests.obj, ...) UseMethod("testswapran")
-getTestPvalue <- function(asrtests.obj, ...) UseMethod("getTestPvalue")
 
-infoCriteria <- function(asreml.obj, ...) UseMethod("infoCriteria")
+bootREMLRT <- function(h0.asreml.obj, h1.asreml.obj, ...) UseMethod("bootREMLRT")
 estimateV <- function(asreml.obj, ...) UseMethod("estimateV")
+getFormulae <- function(asreml.obj, ...) UseMethod("getFormulae")
+infoCriteria <- function(object, ...) UseMethod("infoCriteria")
 newfit <- function(asreml.obj, ...) UseMethod("newfit")
 predictPlus <- function(asreml.obj, ...) UseMethod("predictPlus")
 predictPresent <- function(asreml.obj, ...) UseMethod("predictPresent")
+printFormulae <- function(asreml.obj, ...) UseMethod("printFormulae")
 REMLRT <- function(h0.asreml.obj, h1.asreml.obj, ...) UseMethod("REMLRT")
-bootREMLRT <- function(h0.asreml.obj, h1.asreml.obj, ...) UseMethod("bootREMLRT")
 variofaces <- function(asreml.obj, ...) UseMethod("variofaces")
 
 addBacktransforms <- function(alldiffs.obj, ...) UseMethod("addBacktransforms")
